Struct FactoryListenerLocalBuilder

pub struct FactoryListenerLocalBuilder<'a> { /* private fields */ }
A builder for registering factory event callbacks.

Use Factory::add_listener_local to create this and register callbacks that will be called when events of interest occur. After adding callbacks, use register to get back a FactoryListener.

Examples

let factory_listener = factory.add_listener_local()
    .info(|info| println!("New factory info: {info:?}"))
    .register();

Implementations

Source

impl<'a> FactoryListenerLocalBuilder<'a>

pub fn info<F>(self, info: F) -> Self
where F: Fn(&FactoryInfoRef) + 'static,

Set the factory info event callback of the listener.

Callback parameters

info: Info about the factory

Examples
let factory_listener = factory.add_listener_local()
    .info(|info| println!("New factory info: {info:?}"))
    .register();
pub fn register(self) -> FactoryListener

Subscribe to events and register any provided callbacks.