pub struct FactoryListener { /* private fields */ }Expand description
An owned listener for factory events.
This is created by FactoryListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.